@@ -72,12 +72,18 @@ def _start_web_driver_daemon(wb_pid):
 
 class Device(Events):
     """
-    SyberOS设备类，继承自Events基类，负责驱动设备模拟事件与获取布局信息
+    Device初始化，获取设备初始信息，创建相关子线程与子进程等。\n
+    :param host: 设备通信IP地址(默认为192.168.100.100)
+    :param port: 设备通信端口(默认为10008，一般不需修改)
+    :param _main: 主进程标识符(禁止用户使用)
+    :ivar xml_string: 储存最后一次的设备UI布局信息xml字符串
+    :ivar default_timeout: 框架整体的默认超时时间
+    :ivar control_host_type: 控制端平台类型，枚举类型Controller
     """
     con = Connection()
     __osVersion = ""
     __serialNumber = ""
-    xmlStr = ""
+    xml_string = ""
     __xpath_file = "./xpath_list.ini"
     __screenshots = "./screenshots/"
     default_timeout = 30
@@ -141,6 +147,11 @@ class Device(Events):
         self.__main_conn.send({'watcher_list': self.watcher_list})
 
     def watcher(self, name: str) -> Watcher:
+        """
+        创建一个监视者，可以根据指定条件作出相应反应。\n
+        :param name: 标识名称，不可重复
+        :return: 返回一个实例化的Watcher对象
+        """
         w = Watcher({'name': name}, self)
         return w
 
@@ -172,21 +183,36 @@ class Device(Events):
 
     def set_syslog_output(self, is_enable: bool, keyword: str = "") -> None:
         """
-        设置设备log输出开关
-        :param is_enable:
-        :param keyword:
-        :return:
+        设置设备log输出(打印至控制端标准输出stdout)开关。\n
+        :param is_enable: log输出开关, bool值, True为开启，False为关闭
+        :param keyword: 筛选关键字(筛选最小单位行)，如果为空则全部打印
+        :return: 无
         """
         self.__syslog_output_keyword = keyword
         self.__syslog_output = is_enable
 
     def syslog_output(self) -> bool:
+        """
+        获取设备log输出开关状态。\n
+        :return: log输出开关, bool值, True为开启，False为关闭
+        """
         return self.__syslog_output
 
     def syslog_output_keyword(self) -> str:
+        """
+        查询当前设备log输出时的筛选关键字。\n
+        :return: 关键字字符串
+        """
         return self.__syslog_output_keyword
 
     def set_syslog_save_start(self, save_path: str = "./syslog/", save_name: str = None, save_keyword: str = "") -> None:
+        """
+        设置保存设备log开始。\n
+        :param save_path: 保存文件路径，指定一个文件夹的相对或绝对路径，默认在当前工作目录下的syslog文件夹
+        :param save_name: log文件保存名称，默认以时间戳命名
+        :param save_keyword: 筛选关键字(筛选最小单位行)，如果为空则全部保存
+        :return: 无
+        """
         self.__syslog_save_path = save_path
         if save_name is None:
             current_remote_time = self.con.get(path="getSystemTime").read()
@@ -195,30 +221,70 @@ class Device(Events):
         self.__syslog_save = True
 
     def set_syslog_save_stop(self) -> None:
+        """
+        停止保存设备log，如果不调用此方法则会一直保存至进程结束。\n
+        :return: 无
+        """
         self.__syslog_save = False
 
     def syslog_save(self) -> bool:
+        """
+        获取当前是否正在保存设备log。\n
+        :return: bool值，True为正在保存中，False则相反
+        """
         return self.__syslog_save
 
     def syslog_save_path(self) -> str:
+        """
+        获取当前设备log保存目录。\n
+        :return: 路径字符串
+        """
         return self.__syslog_save_path
 
     def syslog_save_name(self) -> str:
+        """
+        获取当前设备log保存名称。\n
+        :return: 名称字符串
+        """
         return self.__syslog_save_name
 
     def syslog_save_keyword(self) -> str:
+        """
+        获取当前设备log保存筛选关键字。\n
+        :return: 关键字字符串
+        """
         return self.__syslog_save_keyword
 
     def set_default_timeout(self, timeout: int) -> None:
+        """
+        设置当前框架默认超时时间(默认为30秒)。\n
+        :param timeout: 超时时间(单位:秒)
+        :return: 无
+        """
         self.default_timeout = timeout
 
     def set_xpath_list(self, path: str) -> None:
+        """
+        设置存放xpath信息的ini文件路径(默认为当前工作目录下的xpath_list.ini)。\n
+        :param path: 文件路径
+        :return: 无
+        """
         self.__xpath_file = path
 
     def set_screenshots_path(self, path: str) -> None:
+        """
+        设置存放系统截图的文件夹路径(默认为当前工作目录下的screenshots文件夹)。\n
+        :param path: 文件夹路径
+        :return: 无
+        """
         self.__screenshots = path
 
     def screenshot(self, path: str = __screenshots) -> str:
+        """
+        获取设备当前屏幕截图。\n
+        :param path: 截图存放路径(默认为前工作目录下的screenshots文件夹或者用户通过Device.set_screenshots_path(path: str)接口设置的路径)
+        :return: 截图名称
+        """
         if not os.path.exists(path):
             os.makedirs(path)
         img_base64 = str(self.con.get(path="getScreenShot").read(), 'utf-8').split(',')[0]
@@ -230,6 +296,16 @@ class Device(Events):
         return file_name
 
     def grab_image_to_base64(self, x: int, y: int, width: int, height: int, rotation: int = 0, scale: float = 1) -> str:
+        """
+        或去指定位置、大小及状态的范围截图。\n
+        :param x: 范围旋转缩放前的横坐标
+        :param y: 范围旋转缩放前的纵坐标
+        :param width: 范围旋转缩放前的宽度
+        :param height: 范围旋转缩放前的高度
+        :param rotation: 顺时针旋转角度
+        :param scale: 缩放系数
+        :return: 截图的base64形态
+        """
         return str(self.con.get(path="grabImage?x=" + str(round(x))
                               + "&y=" + str(round(y))
                               + "&w=" + str(round(width))
@@ -243,12 +319,26 @@ class Device(Events):
         self.__width = int(image_data.split(",")[2])
 
     def display_width(self) -> int:
+        """
+        获取当前设备屏幕宽度。\n
+        :return: 屏幕宽度像素数int值
+        """
         return self.__width
 
     def display_height(self) -> int:
+        """
+        获取当前设备屏幕高度。\n
+        :return: 屏幕高度像素数int值
+        """
         return self.__height
 
     def get_xpath(self, sop_id: str, key: str) -> str:
+        """
+        通过sopid与key在xpath信息ini文件中查询xpath值。\n
+        :param sop_id: 设备应用的sopid
+        :param key: 键
+        :return: xpath值字符串
+        """
         if not os.path.exists(self.__xpath_file):
             f = open(self.__xpath_file, "w")
             f.close()
@@ -257,18 +347,42 @@ class Device(Events):
         return conf.get(sop_id, key)
 
     def refresh_layout(self) -> None:
-        self.xmlStr = str(self.con.get(path="getLayoutXML").read(), 'utf-8')
+        """
+        刷新当前设备的UI布局信息。\n
+        :return: 无
+        """
+        self.xml_string = str(self.con.get(path="getLayoutXML").read(), 'utf-8')
 
     def os_version(self) -> str:
+        """
+        获取SyberOS系统版本。\n
+        :return: 系统版本字符串
+        """
         return self.__osVersion
 
     def serial_number(self) -> str:
+        """
+        获取当前设备硬件序列号。\n
+        :return: 序列号字符串
+        """
         return self.__serialNumber
     
     def find_item_by_xpath_key(self, sopid: str, xpath_key: str) -> Item:
+        """
+        获取元素控件实例化对象。\n
+        :param sopid: 设备应用的sopid
+        :param xpath_key: xpath信息ini文件中的键
+        :return: Item对象
+        """
         i = Item(d=self, s=sopid, xpath=self.get_xpath(sopid, xpath_key))
         return i
 
     def find_item_by_xpath(self, sopid: str, xpath: str) -> Item:
+        """
+        获取元素控件实例化对象。\n
+        :param sopid: 设备应用的sopid
+        :param xpath: xpath值字符串
+        :return: Item对象
+        """
         i = Item(d=self, s=sopid, xpath=xpath)
         return i
