@@ -52,6 +52,13 @@ class _WorkerThread(threading.Thread):
 
 
 class Item:
+    """
+    元素控件类，通过Device.find_item_by_xpath_key()与Device.find_item_by_xpath()两个结果返回实例化对象，不推荐单独使用。\n
+    :ivar sopid: 元素控件所在的应用sopid
+    :ivar device: 实例化的Device对象
+    :ivar node: 对应的xml节点对象
+    :ivar xpath: xpath字符串
+    """
     node = None
     xpath = ""
     device = None
@@ -71,7 +78,7 @@ class Item:
     def __refresh_node(self):
         self.node = None
         self.device.refresh_layout()
-        selector = etree.XML(self.device.xmlStr.encode('utf-8'))
+        selector = etree.XML(self.device.xml_string.encode('utf-8'))
         nodes = selector.xpath(self.xpath)
         if len(nodes) > 0 and selector.get("sopId") == self.sopid:
             self.node = nodes[0]
@@ -126,106 +133,221 @@ class Item:
         self.__has_contents = bool()
 
     def x(self, refresh: bool = False) -> int:
+        """
+        获取元素控件的横坐标整数值。\n
+        :param refresh: 是否刷新布局信息(默认值False)
+        :return: 横坐标整数值
+        """
         if refresh:
             self.__refresh_node()
         return self.__x
 
     def y(self, refresh: bool = False) -> int:
+        """
+        获取元素控件的纵坐标整数值。\n
+        :param refresh: 是否刷新布局信息(默认值False)
+        :return: 纵坐标整数值
+        """
         if refresh:
             self.__refresh_node()
         return self.__y
 
     def center_x_to_item(self, refresh: bool = False) -> int:
+        """
+        获取元素控件的相对于父对象的映射横坐标整数值。\n
+        :param refresh: 是否刷新布局信息(默认值False)
+        :return: 横坐标整数值
+        """
         if refresh:
             self.__refresh_node()
         return self.__center_x_to_item
 
     def center_y_to_item(self, refresh: bool = False) -> int:
+        """
+        获取元素控件的相对于父对象的映射纵坐标整数值。\n
+        :param refresh: 是否刷新布局信息(默认值False)
+        :return: 纵坐标整数值
+        """
         if refresh:
             self.__refresh_node()
         return self.__center_y_to_item
 
     def center_x_to_global(self, refresh: bool = False) -> int:
+        """
+        获取元素控件的相对于全局的映射横坐标整数值。\n
+        :param refresh: 是否刷新布局信息(默认值False)
+        :return: 横坐标整数值
+        """
         if refresh:
             self.__refresh_node()
         return self.__center_x_to_global
 
     def center_y_to_global(self, refresh: bool = False) -> int:
+        """
+        获取元素控件的相对于全局的映射纵坐标整数值。\n
+        :param refresh: 是否刷新布局信息(默认值False)
+        :return: 纵坐标整数值
+        """
         if refresh:
             self.__refresh_node()
         return self.__center_y_to_global
 
     def z(self, refresh: bool = False) -> int:
+        """
+        获取元素控件的z轴坐标整数值。\n
+        :param refresh: 是否刷新布局信息(默认值False)
+        :return: z轴坐标整数值
+        """
         if refresh:
             self.__refresh_node()
         return self.__z
 
     def scale(self, refresh: bool = False) -> float:
+        """
+        获取元素控件的缩放系数。\n
+        :param refresh: 是否刷新布局信息(默认值False)
+        :return: 缩放系数
+        """
         if refresh:
             self.__refresh_node()
         return self.__scale
 
     def rotation(self, refresh: bool = False) -> int:
+        """
+        获取元素控件的顺时针旋转角度。\n
+        :param refresh: 是否刷新布局信息(默认值False)
+        :return: 角度值
+        """
         if refresh:
             self.__refresh_node()
         return self.__rotation
 
     def clip(self, refresh: bool = False) -> bool:
+        """
+        获取元素控件是否启用了裁切属性。\n
+        :param refresh: 是否刷新布局信息(默认值False)
+        :return: bool值，开启裁切为True，否则为False
+        """
         if refresh:
             self.__refresh_node()
         return self.__clip
 
     def height(self, refresh: bool = False) -> int:
+        """
+        获取元素控件的高度整数值。\n
+        :param refresh: 是否刷新布局信息(默认值False)
+        :return: 高度整数值
+        """
         if refresh:
             self.__refresh_node()
         return self.__height
 
     def width(self, refresh: bool = False) -> int:
+        """
+        获取元素控件的宽度整数值。\n
+        :param refresh: 是否刷新布局信息(默认值False)
+        :return: 宽度整数值
+        """
         if refresh:
             self.__refresh_node()
         return self.__width
 
     def temp_id(self, refresh: bool = False) -> str:
+        """
+        获取元素控件的临时标识符。\n
+        :param refresh: 是否刷新布局信息(默认值False)
+        :return: 标识符字符串
+        """
         if refresh:
             self.__refresh_node()
         return self.__tempId
 
     def text(self, refresh: bool = False) -> str:
+        """
+        获取元素控件的文本信息。\n
+        :param refresh: 是否刷新布局信息(默认值False)
+        :return: 文本字符串
+        """
         if refresh:
             self.__refresh_node()
         return self.__text
 
     def object_name(self, refresh: bool = False) -> str:
+        """
+        获取元素控件的对象名称，此属性对应开发过程中的qml的id属性，但实际此属性在全局并非绝对唯一。\n
+        :param refresh: 是否刷新布局信息(默认值False)
+        :return: 对象名称字符串
+        """
         if refresh:
             self.__refresh_node()
         return self.__objectName
 
     def class_name(self, refresh: bool = False) -> str:
+        """
+        获取元素控件的类名。\n
+        :param refresh: 是否刷新布局信息(默认值False)
+        :return: 类名字符串
+        """
         if refresh:
             self.__refresh_node()
         return self.__className
 
     def opacity(self, refresh: bool = False) -> float:
+        """
+        获取元素控件的透明度(0-1的浮点数)。\n
+        :param refresh: 是否刷新布局信息(默认值False)
+        :return: 透明度值
+        """
         if refresh:
             self.__refresh_node()
         return self.__opacity
 
     def enabled(self, refresh: bool = False) -> bool:
+        """
+        获取元素控件的enabled属性。\n
+        :param refresh: 是否刷新布局信息(默认值False)
+        :return: 属性值，True为开启，否则为False
+        """
         if refresh:
             self.__refresh_node()
         return self.__enabled
 
     def visible(self, refresh: bool = False) -> bool:
+        """
+        获取元素控件的可访问属性。\n
+        :param refresh: 是否刷新布局信息(默认值False)
+        :return: 属性值，True为开启，否则为False
+        """
         if refresh:
             self.__refresh_node()
         return self.__visible
 
     def focus(self, refresh: bool = False) -> bool:
+        """
+        获取元素控件是否拥有焦点。\n
+        :param refresh: 是否刷新布局信息(默认值False)
+        :return: 属性值，拥有焦点为True，否则为False
+        """
         if refresh:
             self.__refresh_node()
         return self.__focus
 
+    def has_contents(self, refresh: bool = False) -> bool:
+        """
+        判断元素控件是否拥有可视内容。\n
+        :param refresh: 是否刷新布局信息(默认值False)
+        :return: 属性值，拥有可视内容为True，否则为False
+        """
+        if refresh:
+            self.__refresh_node()
+        return self.__has_contents
+
     def exist(self, timeout: int = None) -> bool:
+        """
+        判断元素控件是否显示。\n
+        :param timeout: 超时时间(单位:秒)，默认为框架超时时间
+        :return: 显示为True，超时未显示为False
+        """
         if timeout is None:
             timeout = self.device.default_timeout
         die_time = int(time.time()) + timeout
@@ -243,7 +365,7 @@ class Item:
         if self.node is not None and self.__visible and self.__opacity > 0 and self.__scale != 0 and self.__width > 0 and self.__height > 0:
             image = []
             if self.device.control_host_type == 0:
-                tree = xml.dom.minidom.parseString(self.device.xmlStr)
+                tree = xml.dom.minidom.parseString(self.device.xml_string)
                 for node in tree.documentElement.childNodes:
                     for n in node.childNodes:
                         if len(image) == 0:
@@ -251,7 +373,7 @@ class Item:
                         else:
                             image = self.__img_cover(image, self.__xml_tree_traversed(n.childNodes, 1))
             else:
-                html_string = self.device.libsr.go(c_char_p(bytes(self.device.xmlStr, "utf-8")),
+                html_string = self.device.libsr.go(c_char_p(bytes(self.device.xml_string, "utf-8")),
                                                    c_char_p(bytes(self.__tempId, "utf-8")),
                                                    c_int(self.__display_width),
                                                    c_int(self.__display_height))
@@ -618,11 +740,22 @@ class Item:
         return image
 
     def click(self, delay: int = 0) -> bool:
+        """
+        点击元素控件。\n
+        :param delay: 点击延时时间(单位:毫秒), 默认无延时
+        :return: 成功返回True，否则为False
+        """
         if self.node is not None:
             self.device.click(Point(self.__center_x_to_global, self.__center_y_to_global), delay)
         return False
 
-    def click_exist(self, timeout: int = None) -> bool:
+    def click_exist(self, delay: int = 0, timeout: int = None) -> bool:
+        """
+        判断元素控件是否显示，显示则执行点击操作。\n
+        :param delay: 点击延时时间(单位:毫秒), 默认无延时
+        :param timeout: 超时时间(单位:秒)，默认为框架超时时间
+        :return: 成功返回True，否则为False
+        """
         if self.exist(timeout):
             if (self.rect[len(self.rect) - 1][1] - self.rect[0][1] + 1) \
                     * (self.rect[len(self.rect) - 1][0] - self.rect[0][0] + 1) == len(self.rect):
@@ -630,10 +763,15 @@ class Item:
                 y = self.rect[0][0] + int((self.rect[len(self.rect) - 1][0] - self.rect[0][0] + 1) / 2)
                 self.device.click(Point(x, y))
                 return True
-            self.device.click(Point(self.rect[100][1], self.rect[100][0]))
+            self.device.click(Point(self.rect[100][1], self.rect[100][0]), delay)
             return True
         return False
 
     def submit_string(self, text: str) -> bool:
+        """
+        向元素控件提交文本(模拟输入法事件)。\n
+        :param text: 要提交的文本字符串
+        :return: 成功返回True，否则为False
+        """
         self.click()
         return self.device.submit_string(text)
